@@ -22,5 +22,7 @@
 
 from __future__ import annotations
 
-# provide vat as an alias
+# provide aliases
+from stdnum.ee import ik as personalid  # noqa: F401
 from stdnum.ee import kmkr as vat  # noqa: F401
+from stdnum.ee import registrikood as businessid  # noqa: F401
