@@ -22,5 +22,6 @@
 
 from __future__ import annotations
 
-# provide vat as an alias
+# provide excise and vat as an alias
+from stdnum.fr import accise as excise  # noqa: F401
 from stdnum.fr import tva as vat  # noqa: F401
